==> arg-services-1.1.0-sources.jar: de/uni_trier/recap/arg_services/mining/v1beta/EntailmentServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.52.1)",
    comments = "Source: arg_services/mining/v1beta/entailment.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class EntailmentServiceGrpc {

  private EntailmentServiceGrpc() {}

  public static final String SERVICE_NAME = "arg_services.mining.v1beta.EntailmentService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse> getEntailmentMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Entailment",
      requestType = de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse> getEntailmentMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest, de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse> getEntailmentMethod;
    if ((getEntailmentMethod = EntailmentServiceGrpc.getEntailmentMethod) == null) {
      synchronized (EntailmentServiceGrpc.class) {
        if ((getEntailmentMethod = EntailmentServiceGrpc.getEntailmentMethod) == null) {
          EntailmentServiceGrpc.getEntailmentMethod = getEntailmentMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest, de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Entailment"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse.getDefaultInstance()))
              .setSchemaDescriptor(new EntailmentServiceMethodDescriptorSupplier("Entailment"))
              .build();
        }
      }
    }
    return getEntailmentMethod;
  }

  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> getEntailmentsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Entailments",
      requestType = de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> getEntailmentsMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest, de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> getEntailmentsMethod;
    if ((getEntailmentsMethod = EntailmentServiceGrpc.getEntailmentsMethod) == null) {
      synchronized (EntailmentServiceGrpc.class) {
        if ((getEntailmentsMethod = EntailmentServiceGrpc.getEntailmentsMethod) == null) {
          EntailmentServiceGrpc.getEntailmentsMethod = getEntailmentsMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest, de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Entailments"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse.getDefaultInstance()))
              .setSchemaDescriptor(new EntailmentServiceMethodDescriptorSupplier("Entailments"))
              .build();
        }
      }
    }
    return getEntailmentsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static EntailmentServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceStub>() {
        @java.lang.Override
        public EntailmentServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentServiceStub(channel, callOptions);
        }
      };
    return EntailmentServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static EntailmentServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceBlockingStub>() {
        @java.lang.Override
        public EntailmentServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentServiceBlockingStub(channel, callOptions);
        }
      };
    return EntailmentServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static EntailmentServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceFutureStub>() {
        @java.lang.Override
        public EntailmentServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentServiceFutureStub(channel, callOptions);
        }
      };
    return EntailmentServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class EntailmentServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void entailment(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getEntailmentMethod(), responseObserver);
    }

    /**
     */
    public void entailments(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getEntailmentsMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getEntailmentMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest,
                de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse>(
                  this, METHODID_ENTAILMENT)))
          .addMethod(
            getEntailmentsMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest,
                de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse>(
                  this, METHODID_ENTAILMENTS)))
          .build();
    }
  }

  /**
   */
  public static final class EntailmentServiceStub extends io.grpc.stub.AbstractAsyncStub<EntailmentServiceStub> {
    private EntailmentServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentServiceStub(channel, callOptions);
    }

    /**
     */
    public void entailment(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getEntailmentMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void entailments(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getEntailmentsMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class EntailmentServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<EntailmentServiceBlockingStub> {
    private EntailmentServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse entailment(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getEntailmentMethod(), getCallOptions(), request);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse entailments(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getEntailmentsMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class EntailmentServiceFutureStub extends io.grpc.stub.AbstractFutureStub<EntailmentServiceFutureStub> {
    private EntailmentServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse> entailment(
        de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getEntailmentMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> entailments(
        de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getEntailmentsMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_ENTAILMENT = 0;
  private static final int METHODID_ENTAILMENTS = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final EntailmentServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(EntailmentServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_ENTAILMENT:
          serviceImpl.entailment((de.uni_trier.recap.arg_services.mining.v1beta.EntailmentRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentResponse>) responseObserver);
          break;
        case METHODID_ENTAILMENTS:
          serviceImpl.entailments((de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class EntailmentServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    EntailmentServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining.v1beta.EntailmentProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("EntailmentService");
    }
  }

  private static final class EntailmentServiceFileDescriptorSupplier
      extends EntailmentServiceBaseDescriptorSupplier {
    EntailmentServiceFileDescriptorSupplier() {}
  }

  private static final class EntailmentServiceMethodDescriptorSupplier
      extends EntailmentServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    EntailmentServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (EntailmentServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new EntailmentServiceFileDescriptorSupplier())
              .addMethod(getEntailmentMethod())
              .addMethod(getEntailmentsMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> arg-services-1.5.9-sources.jar: de/uni_trier/recap/arg_services/mining/v1beta/EntailmentServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: arg_services/mining/v1beta/entailment.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class EntailmentServiceGrpc {

  private EntailmentServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "arg_services.mining.v1beta.EntailmentService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> getEntailmentsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Entailments",
      requestType = de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> getEntailmentsMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest, de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> getEntailmentsMethod;
    if ((getEntailmentsMethod = EntailmentServiceGrpc.getEntailmentsMethod) == null) {
      synchronized (EntailmentServiceGrpc.class) {
        if ((getEntailmentsMethod = EntailmentServiceGrpc.getEntailmentsMethod) == null) {
          EntailmentServiceGrpc.getEntailmentsMethod = getEntailmentsMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest, de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Entailments"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse.getDefaultInstance()))
              .setSchemaDescriptor(new EntailmentServiceMethodDescriptorSupplier("Entailments"))
              .build();
        }
      }
    }
    return getEntailmentsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static EntailmentServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceStub>() {
        @java.lang.Override
        public EntailmentServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentServiceStub(channel, callOptions);
        }
      };
    return EntailmentServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static EntailmentServiceBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceBlockingV2Stub>() {
        @java.lang.Override
        public EntailmentServiceBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentServiceBlockingV2Stub(channel, callOptions);
        }
      };
    return EntailmentServiceBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static EntailmentServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceBlockingStub>() {
        @java.lang.Override
        public EntailmentServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentServiceBlockingStub(channel, callOptions);
        }
      };
    return EntailmentServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static EntailmentServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentServiceFutureStub>() {
        @java.lang.Override
        public EntailmentServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentServiceFutureStub(channel, callOptions);
        }
      };
    return EntailmentServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void entailments(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getEntailmentsMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service EntailmentService.
   */
  public static abstract class EntailmentServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return EntailmentServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service EntailmentService.
   */
  public static final class EntailmentServiceStub
      extends io.grpc.stub.AbstractAsyncStub<EntailmentServiceStub> {
    private EntailmentServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentServiceStub(channel, callOptions);
    }

    /**
     */
    public void entailments(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getEntailmentsMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service EntailmentService.
   */
  public static final class EntailmentServiceBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<EntailmentServiceBlockingV2Stub> {
    private EntailmentServiceBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentServiceBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentServiceBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse entailments(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getEntailmentsMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service EntailmentService.
   */
  public static final class EntailmentServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<EntailmentServiceBlockingStub> {
    private EntailmentServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse entailments(de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getEntailmentsMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service EntailmentService.
   */
  public static final class EntailmentServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<EntailmentServiceFutureStub> {
    private EntailmentServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse> entailments(
        de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getEntailmentsMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_ENTAILMENTS = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_ENTAILMENTS:
          serviceImpl.entailments((de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getEntailmentsMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsRequest,
              de.uni_trier.recap.arg_services.mining.v1beta.EntailmentsResponse>(
                service, METHODID_ENTAILMENTS)))
        .build();
  }

  private static abstract class EntailmentServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    EntailmentServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining.v1beta.EntailmentProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("EntailmentService");
    }
  }

  private static final class EntailmentServiceFileDescriptorSupplier
      extends EntailmentServiceBaseDescriptorSupplier {
    EntailmentServiceFileDescriptorSupplier() {}
  }

  private static final class EntailmentServiceMethodDescriptorSupplier
      extends EntailmentServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    EntailmentServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (EntailmentServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new EntailmentServiceFileDescriptorSupplier())
              .addMethod(getEntailmentsMethod())
              .build();
        }
      }
    }
    return result;
  }
}
